@@ -1,7 +1,9 @@
+#modified Sept 5, 2016 to sort Structure as well as loadings
 "fa.sort" <- 
 function(fa.results,polar=FALSE) {
   omega <- FALSE
   con.i <- FALSE
+  Structure <- NULL  #in case we are not doing fa
   if(length(class(fa.results)) > 1)  { value <- class(fa.results)[2] } else {value="other"}
 
 switch(value, 
@@ -19,12 +21,14 @@ fa.ci = {factors <- fa.results$loadings
 iclust = {factors <- as.matrix(fa.results$loadings)
              if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
 fa = {factors <- as.matrix(fa.results$loadings)
-             if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
+             if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}
+             Structure <- fa.results$Structure},
 principal = {factors <- as.matrix(fa.results$loadings)
              if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
 extension = {factors <- as.matrix(fa.results$loadings)
              if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
 extend = {factors <- as.matrix(fa.results$loadings)
+               if(!is.null(fa.results$Structure)) Structure <- fa.results$Structure
              if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
 other = {factors <- fa.results})
 
@@ -44,6 +48,10 @@ loads <- data.frame(item=seq(1:nitems),cluster=rep(0,nitems))
   		 loads$cluster <- apply(abs(factors),1,which.max)
  		 ord <- sort(loads$cluster,index.return=TRUE)
   		factors[1:nitems,] <- factors[ord$ix,]
+  		if(!is.null(Structure)) {Structure[1:nitems,] <- Structure[ord$ix,]
+  		 rownames(Structure)[1:nitems] <- rownames(Structure)[ord$ix]
+  		 }
+  		
  		rownames(factors)[1:nitems] <- rownames(factors)[ord$ix]
         total.ord <- ord$ix
         if(con.i) { ci[1:nitems,] <- ci[ord$ix,] #if we are doing confidence intervals
@@ -62,7 +70,11 @@ loads <- data.frame(item=seq(1:nitems),cluster=rep(0,nitems))
 				ord <- sort(abs(factors[first:last,i]),decreasing=TRUE,index.return=TRUE)
    				factors[first:last,] <- factors[item[ord$ix+first-1],]
    				loads[first:last,1] <- item[ord$ix+first-1]
+   				if(!is.null(Structure) ) {Structure[first:last,] <- Structure[item[ord$ix+first-1],]
+   				rownames(Structure)[first:last] <- rownames(Structure)[ord$ix+first-1]
+   				}
    				rownames(factors)[first:last] <- rownames(factors)[ord$ix+first-1]
+   				
    			
    				if(con.i) { ci[first:last,] <- ci[item[ord$ix+first-1],] #if we are doing confidence intervals
                             cip[first:last,] <- cip[item[ord$ix+first-1],] }
@@ -113,6 +125,8 @@ loads <- data.frame(item=seq(1:nitems),cluster=rep(0,nitems))
        if(is.list(fa.results))  {fa.results$order <- total.ord 
          fa.results$complexity <- fa.results$complexity[total.ord]
          fa.results$communality <- fa.results$communality[total.ord]
-         fa.results$uniquenesses <- fa.results$uniquenesses[total.ord]}
+         fa.results$uniquenesses <- fa.results$uniquenesses[total.ord]
+         if(!is.null(Structure)) { fa.results$Structure <- Structure}
+         }
           return(fa.results)
          }     
